#
# spec file for package accel-config
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pkg_libname libaccel-config1
%define src_name idxd-config-accel-config-v%{version}
Name:           accel-config
Version:        4.1.8
Release:        1.4
Summary:        Configure accelerator subsystem devices
License:        GPL-2.0-only
URL:            https://github.com/intel/idxd-config
Source:         %{url}/archive/accel-config-v%{version}.tar.gz#/%{src_name}.tar.gz
BuildRequires:  asciidoc
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  binutils
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  xmlto
BuildRequires:  pkgconfig(json-c)
BuildRequires:  pkgconfig(uuid)
Requires:       %{pkg_libname} = %{version}-%{release}
ExclusiveArch:  x86_64

%description
Utility library and command-line tool for configuring the Intel
Data Streaming Accelerator (DSA) and Intel Analytics Accelerator
(IAX).

%package -n %{name}-devel
Summary:        Development files for libaccfg
License:        LGPL-2.1-only
Requires:       %{pkg_libname} = %{version}-%{release}

%description -n %{name}-devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package -n %{pkg_libname}
Summary:        Configuration library for accelerator subsystem devices
License:        LGPL-2.1-only
Requires:       kmod(idxd.ko)

%description -n %{pkg_libname}
Libraries for %{name}.

%prep
%setup -q -n %{src_name}

%build
echo %{version} > version
./autogen.sh
%configure
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{pkg_libname} -p /sbin/ldconfig
%postun -n %{pkg_libname} -p /sbin/ldconfig

%files
%license Documentation/COPYING licenses/BSD-MIT licenses/CC0
%license licenses/accel-config-licenses LICENSE_GPL_2_0
%{_bindir}/accel-config
%{_mandir}/man1/accel-config*
%dir %{_sysconfdir}/accel-config
%dir %{_sysconfdir}/accel-config/contrib
%dir %{_sysconfdir}/accel-config/contrib/configs
%config %{_sysconfdir}/accel-config/contrib/configs/app_profile.conf
%config %{_sysconfdir}/accel-config/contrib/configs/net_profile.conf
%config %{_sysconfdir}/accel-config/contrib/configs/os_profile.conf
%config %{_sysconfdir}/accel-config/contrib/configs/profilenote.txt
%config %{_sysconfdir}/accel-config/contrib/configs/storage_profile.conf
%config %{_sysconfdir}/accel-config/contrib/configs/user_default_profile.conf

%files -n %{pkg_libname}
%doc README.md
%license Documentation/COPYING licenses/BSD-MIT licenses/CC0
%license licenses/libaccel-config-licenses accfg/lib/LICENSE_LGPL_2_1
%{_libdir}/libaccel-config.so.*

%files -n %{name}-devel
%license Documentation/COPYING
%{_includedir}/accel-config/
%{_libdir}/libaccel-config.so
%{_libdir}/pkgconfig/libaccel-config.pc

%changelog
* Thu Aug  8 2024 Antonio Teixeira <antonio.teixeira@suse.com>
- Update to 4.1.8:
  * Check for error return from iaa_do_crypto
  * Clean up resource leak in accfg_wq_get_occupancy
  * Update dsa_config_test_runner.sh
- 4.1.7 changelog:
  * Typo fixes
  * Make verbose logging optional
  * Clean up typo
  * Don't attempt to disable non-existent devices
  * Don't list attributes not present
  * add required SECURITY.md file for OSSF Scorecard compliance
* Mon Mar 18 2024 Dirk Müller <dmueller@suse.com>
- update to 4.1.6:
  * Free driver_name when freeing wq
  * Disable all WQs and rmmod iaa_crypto
  * Remove the script about vfio passthrough device
  * Use madvise(MADV_DONTNEED) to ummap address
* Thu Feb 15 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 4.1.5:
  + Free driver_name in case of error adding wq.
  + change op config default value because of kernel change.
  + set read buffer allowed from 0 to 8.
  + disable enabled devices before unloading iaa_crypto.
* Thu Jan 18 2024 Danilo Spinella <danilo.spinella@suse.com>
- Update to versione 4.1.4:
  * Fix a bug while reading json objects
  * Do not save traffic class attributes
  * Handle cmd_status initialization failure without exiting
  * Remove SET_ERR macro which is error prone
  * Skip check for ats_disable if attribute absent
  * Add parameter for specifying dev and wq
  * Fix bug about checking result of decompression
- Update to version 4.1.3:
  * be less greedy in _cleanup greps
- Update to version 4.1.2:
  * Fix a memory leak bug
- Update to version 4.1.1:
  * update Standards-Version to 4.6.2 in control file
  * Use asm volatile for compilers that don't support
    __builtin_ia32_mfence
  * Fixes for pedantic compiler warnings
  * Update copyright years in man pages
  * Fix some syntax errors and cleanup in man pages
  * Fix --help and other options
  * Fix a bug with empty wq driver name
  * Fix bug about finding a mismatched wq
  * Add op mask to check if an op is available
  * Decide whether to do the operation or not
  * Fix batch event log core check output issues
  * Provide --skip-config to run dsa tests without device reset
* Wed Aug 30 2023 Danilo Spinella <danilo.spinella@suse.com>
- Update to version 4.1:
  * add missing libssl-dev dependency
  * Skip configuring ats_disable if the attribute is not present
  * Add config-user-default command
  * Add option "-c <config_file>" to load default configurations from
    the file
  * Disable default configured WQs and devices
  * Add "-n <wq_name>" to specify WQ name for disabling WQs
  * Add user_default_profile.conf
  * Add doumentation for new command "config-user-default"
* Fri Apr 28 2023 Danilo Spinella <danilo.spinella@suse.com>
- Update to version 4.0:
  * use buildflags.mk, remove hardcoded CFLAGS
  * debian/accel-config-test.install fix path on copy
  * convert all magic number for 1<<12 to PAGE_SIZE
  * fix madvise() call to unmap pages
  * add updated idxd.h definition from kernel source
  * Remove redundant -f 0x0 in iaa_user_test_runner.sh
  * Fix dedicated mode wq size 1 failure
  * Modify incorrect print information
  * Modify block_on_fault in 2g2q_user_2.conf
  * Move get_random_value() to accel_test.c
  * Add algorithm to do Zcompress8
  * Add test code of operation Zcompress8
  * Modify script for executing Zcompress8 test
  * Add algorithm to do Zdecompress8
  * Add test code of operation Zdecompress8
  * Modify script for executing Zdecompress8 test
  * Add algorithm to do both Encrypt and Decrypt
  * Add test code of operation Encrypt
  * Modify script for executing Encrypt test
  * Add test code of operation Decrypt
  * Modify script for executing Decrypt test
  * Modify struct in idxd.h for IAA Translation Fetch
  * Add test code of IAA Translation Fetch
  * Modify script for executing IAA Translation Fetch test
  * Add helping information for new parameters
  * Add openssl package installation details
  * Fix bug of Zcompress8 about input size less 128
  * Remove ats_disable config for iax tests
  * Add identification for IAA1.0/2.0 platform
  * add per-wq prs disable tests
  * Update format bitmask attrs to match driver
  * Add new API to set and get wq op_config
  * Add option to config-wq to set op_config
  * Change json listing format of bitmasks
  * Add load, save and list config support for op_config
  * Update config-wq doc with op_config details
  * Add unit test for op_config configuration
  * Fix segmentation fault during list cmd in SPR
  * Add API to retrieve iaa_cap when available
  * Add group->desc_progress_limit support
  * Add group->batch_progress_limit support
  * Add wq->prs_disable support
  * Add device->event_log_size support
  * Do not set traffic class in tests
  * Skip op_config test if feature not present
  * Include IAA support in README
  * Fix bug in return value of pasid enabled check
  * add DIX Generate operation support
  * add translation fetch operation support
  * Remove traffic config for iax tests
  * Fix dsa_test segmentation fault when do 2G tests
- Update to version 3.5.3:
  * Fix bug of setting max destination size
  * Remove some leftover references to mdev
  * Remove text about installing kernel headers
  * Remove uninitialized local variable warning
  * Remove read_buffers 0 settings from configs
* Tue Dec 27 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.5.2:
  * Bug fix in help system
  * Remove mdev implementation
* Fri Nov 18 2022 Danilo Spinella <danilo.spinella@suse.com>
- Update to version 3.5.0:
  * Fix static code analysis warnings
  * Fix lintian errors
  * Move test program and related configs to /usr/lib
  * Move contrib/configs/* to /etc
  * Some code cleanup
* Mon Oct 10 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 3.4.8
  * Changes in accel-config test
* Wed Sep 14 2022 Danilo Spinella <danilo.spinella@suse.com>
- Update to version 3.4.7:
  * No relevant changes
- Update to version 3.4.6.5:
  * Add Zcompress32, Zdecompress32, Compress and Decompress test
  * Add Zcompress16 and Zdecompress16 to IAA test
  * Add operation CRC64 into IAA test
  * Bug fixes
* Mon May 16 2022 Danilo Spinella <danilo.spinella@suse.com>
- Update to version 3.4.6.4:
  * Init IAA test and add No-op operation
  * Separate common codes from DSA source code file
  * Bug fixes
* Thu Apr 21 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.4.6.3:
  * Allow use of config files with driver_name attr with older drivers
* Wed Mar 30 2022 Danilo Spinella <danilo.spinella@suse.com>
- Update to version 3.4.6.2:
  * Allow driver_name to be configured in guest
  * Disable mdev tests
  * Update driver_name in unit test configs
  * Improve error message in config attr failures
- Update to version 3.4.6.1:
  * Bug fix in wq driver name configuration
  * Test configs add driver name attr
- Update to version 3.4.6:
  * Support new "read_buffer" attributes that replace "token" attributes
  * Deprecate attributes with "token" names
  * Add support for driver_name attr to get wq driver name
  * Fix a read buffer length related bug
  * Add opcode operation support
- Build exclusively on x86_64, as kernel module idxd.ko cannot be
  found on i586
* Thu Dec 30 2021 Danilo Spinella <danilo.spinella@suse.com>
- Update to version 3.4.4:
  * Add -e/--enable and -f/--force features to load-config command
  * Add more sample configuration files for different usages
  * Add multi-descriptor support
- Update to version 3.4.3:
  * Remove redundant dependencies (kmod and udev)
  * Bug fixes and code cleanup
  * DSA test adds device and wq selection
  * DSA test adds no opcode operation support
* Fri Oct  8 2021 Danilo Spinella <danilo.spinella@suse.com>
- Update to version 3.4.2
  * Add feature to skip tests based on feature availability
  * Skip tests requiring shared memory if feature not available
  * Add API to retrieve wq occupancy attribute
* Thu Sep  9 2021 Danilo Spinella <danilo.spinella@suse.com>
- Update to version 3.4.1
  * Bug fixes related to traffic-class
  * Add per-wq ATS disable support
  * Add extended error status reporting
  * Created local copy of UAPI header file idxd.h from /usr/include
  * Update driver name changes
  * Rewrite unit test removing hardcoding and other enhancements
  * Bug fixes
- Run spec-cleaner
* Tue Jun 29 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.2
  * Add support for new device bind paths retaining compatibility
    with older kernels
  * Add support for UACCE interface to access char devices
  * Fixed several issues in filtering, config and listing code
  * Support all 256 bits of op_cap
  * Fix incorrect return values
  * Made removing all mdevs more intuitive
* Mon Apr 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 3.1
  * Improved error messages and return values
  * Fix incorrect error return value from tool
  * Allow -1 special value for wq->groupid and fix related error
    messages
  * Fix incorrect manpage text for config-wq
  * Remove reference to non-interface header in interface header
  * Remove non-interface header from packaging
  * Use portable data types and fix build issues in 32 bit targets
- Dropped upstream merged v3.0.1-use-portable-data-types.patch
* Fri Feb 12 2021 Libor Pechacek <lpechacek@suse.com>
- Update to v3.0.1 (jsc#SLE-13348)
  - Added IAX support
  - Added implementation and support for new mdev types
  - Removed uuid type mdevs
  - Introduced a new wq API to set max batch and transfer size
  - Added new GPL2 and LGPL-2.1 license files
  - Library license changed to LGPL-2.1
  - Fixed static code analysis bugs
- Enhanced Description
- Added dependency on the idxd kernel driver
- Restricted architecture to x86 - DSA is embedded
  into Intel CPUs
- Added patch: v3.0.1-use-portable-data-types.patch
* Tue Sep 22 2020 Marketa Calabkova <mcalabkova@suse.com>
- Initial packaging of v2.8 (jsc#SLE-15021)
